package com.ynet.life.sujrb.file.parser;

import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.format.LifeFormat;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchPaySummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchPayExcelFileParser.class */
public class BatchPayExcelFileParser implements BatchFileParserInterface {
    private String formatter;

    public BatchPayExcelFileParser() {
    }

    public BatchPayExcelFileParser(String formatter) {
        this.formatter = formatter;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        int max;
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BatchPaySummary result = new BatchPaySummary();
            int recordNumberInput = 0;
            new BigDecimal("0");
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                int rowIndex0 = 2;
                Boolean flag = Boolean.FALSE;
                while (true) {
                    int i = rowIndex0;
                    rowIndex0++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (recordRow == null) {
                        break;
                    }
                    if (nvl(getCellContent(recordRow, 0, true), "").replaceAll("\t", "").trim().equals("结束")) {
                        flag = Boolean.TRUE;
                        break;
                    }
                }
                if (!flag.booleanValue()) {
                    throw new TranFailException("ebcb0507", "文件不正确缺失结束行");
                }
                int rowIndex = 2;
                while (true) {
                    int i2 = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow2 = sheet.getRow(i2);
                    if (recordRow2 != null && !nvl(getCellContent(recordRow2, 0, true), "").replaceAll("\t", "").trim().equals("结束")) {
                        recordNumberInput++;
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow2));
                        } else {
                            result.addRecord(getRecordMap(recordRow2, this.formatter));
                        }
                    } else {
                        try {
                            max = Integer.parseInt(LifeStandard.getSystemParam("CB_BATCH_TRANSFER_MAX_NUM"));
                        } catch (NumberFormatException unused) {
                            max = 1500;
                        }
                        if (recordNumberInput > max) {
                            Trace.logWarning("LifeAction", "EBCB0505::提交文件总笔数超过要求的值");
                            throw new TranFailException("EBCB0505", "提交文件总笔数超过要求的值", false);
                        }
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw FileConstants.EXCEPTION_PARSE_FAIL;
            } catch (TranFailException e) {
                Trace.logError("LifeAction", "解析文件异常", e);
                throw e;
            }
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("EBLN0000", "文件读取失败", ex2);
        }
    }

    public String nvl(Object dataValue, String returnValue) {
        return LifeFormat.nvl(dataValue, returnValue);
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String orgCode = nvl(getCellContent(recordRow, 0, true), "").replaceAll("\t", "").replaceAll("\n", "").trim();
        String companyName = nvl(getCellContent(recordRow, 1, true), "").replaceAll("\t", "").replaceAll("\n", "").trim();
        String insurAmt = nvl(getCellContent(recordRow, 2, true), "").replaceAll("\t", "").replaceAll("\n", "").trim();
        String usedAmt = nvl(getCellContent(recordRow, 3, true), "").replaceAll("\t", "").replaceAll("\n", "").trim();
        String idelAmt = nvl(getCellContent(recordRow, 4, true), "").replaceAll("\t", "").replaceAll("\n", "").trim();
        if (orgCode.equals("")) {
            throw new TranFailException("ebcb0506", "企业组织机构代码不能为空");
        }
        if (!Pattern.compile("[0-9a-zA-Z]*-?[0-9a-zA-Z]*-?[0-9a-zA-Z]*-?[0-9a-zA-Z]*").matcher(orgCode).matches()) {
            throw new TranFailException("ebcb0507", "企业组织机构代码不合法");
        }
        if (companyName.equals("")) {
            throw new TranFailException("ebcb0506", "企业名称不能为空");
        }
        if (!Pattern.compile("[a-zA-Z0-9一-龥()（）]{1,50}").matcher(companyName).matches()) {
            throw new TranFailException("ebcb0507", "企业名称不合法");
        }
        if (insurAmt.equals("")) {
            throw new TranFailException("ebcb0506", "信保总额度不能为空");
        }
        if (!Pattern.compile("[0-9]*").matcher(insurAmt).matches()) {
            throw new TranFailException("ebcb0507", "信保总额度只能为正整数");
        }
        if (usedAmt.equals("")) {
            throw new TranFailException("ebcb0506", "已使用信保额度不能为空");
        }
        Pattern p = Pattern.compile("[0-9]*");
        if (!p.matcher(usedAmt).matches()) {
            throw new TranFailException("ebcb0507", "已使用信保额度只能为正整数");
        }
        if (idelAmt.equals("")) {
            throw new TranFailException("ebcb0506", "信保剩余额度不能为空");
        }
        Pattern.compile("[0-9]*");
        if (!p.matcher(idelAmt).matches()) {
            throw new TranFailException("ebcb0507", "已使用信保额度只能为正整数");
        }
        result.put("orgCode", orgCode);
        result.put("companyName", companyName);
        result.put("insurAmt", insurAmt);
        result.put("usedAmt", usedAmt);
        result.put("idelAmt", idelAmt);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell == null || cell.equals("")) {
                return "";
            }
            switch (cell.getCellType()) {
                case 0:
                    String format = "######.##";
                    if (toInt) {
                        format = "#######";
                    }
                    result = new DecimalFormat(format).format(cell.getNumericCellValue());
                    break;
                case 1:
                    result = cell.getRichStringCellValue().getString();
                    break;
            }
            return result;
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
